@@ -78,6 +78,15 @@ sub do_checkin {
     my ( $return, $messages, $issue, $borrower );
 
     my $item = Koha::Items->find( { barcode => $barcode } );
+    if ($item) {
+        my $waiting_holds_to_be_cancelled = $item->holds->waiting->filter_by_has_cancellation_requests;
+        while ( my $hold = $waiting_holds_to_be_cancelled->next ) {
+            my $cancellation_request = $hold->cancellation_requests;
+            $cancellation_request->delete;
+            my $cancel_params->{cancellation_reason} = "Cancelled by SIP";
+            $hold->cancel($cancel_params);
+        }
+    }
 
     my $human_required = 0;
     if (   C4::Context->preference("CircConfirmItemParts")
