@@ -1219,7 +1219,6 @@ sub has_restricting_overdues {
 # Fetch first delayX value from overduerules where debarredX is set, or 0 for no delay
 sub _get_overdue_debarred_delay {
     my ( $branchcode, $categorycode ) = @_;
-    my $dbh = C4::Context->dbh();
 
     # We get default rules if there is no rule for this branch
     my $rule = Koha::OverdueRules->find(
@@ -1804,9 +1803,11 @@ disabled.
 sub account_locked {
     my ($self) = @_;
     my $FailedLoginAttempts = C4::Context->preference('FailedLoginAttempts');
-    return 1 if $FailedLoginAttempts
-          and $self->login_attempts
-          and $self->login_attempts >= $FailedLoginAttempts;
+    return 1
+        if $FailedLoginAttempts
+        && $FailedLoginAttempts > 0
+        && $self->login_attempts
+        && $self->login_attempts >= $FailedLoginAttempts;
     return 1 if ($self->login_attempts || 0) < 0; # administrative lockout
     return 0;
 }
