@@ -349,7 +349,7 @@ sub _get_record {
 
     if ( $self->index eq $Koha::SearchEngine::BIBLIOS_INDEX ) {
         my $biblio = Koha::Biblios->find($record_id);
-        $record = $biblio->metadata->record( { embed_items => 1 } )
+        $record = $biblio->metadata_record( { embed_items => 1 } )
           if $biblio;
     } else {
         $record = C4::AuthoritiesMarc::GetAuthority($record_id);
