@@ -23,40 +23,21 @@ use Template::Plugin;
 use base qw( Template::Plugin );
 
 use Koha::Holds;
-use Koha::Biblios;
-use Koha::Patrons;
-use Koha::ArticleRequests;
+use Koha::Database;
 use Koha::Recalls;
 
+# Do not use HoldsCount, it is deprecated and will be removed in a future release.
 sub HoldsCount {
     my ( $self, $biblionumber ) = @_;
 
+    warn "HoldsCount is deprecated, you should use biblio.holds.count instead";
+
     my $holds = Koha::Holds->search( { biblionumber => $biblionumber } );
 
     return $holds->count();
 }
 
-sub ArticleRequestsActiveCount {
-    my ( $self, $biblionumber ) = @_;
-
-    my $ar = Koha::ArticleRequests->search(
-        {
-            biblionumber => $biblionumber
-        }
-    )->filter_by_current;
-
-    return $ar->count();
-}
-
-sub CanArticleRequest {
-    my ( $self, $biblionumber, $borrowernumber ) = @_;
-
-    my $biblio = Koha::Biblios->find( $biblionumber );
-    my $borrower = Koha::Patrons->find( $borrowernumber );
-
-    return $biblio ? $biblio->can_article_request( $borrower ) : 0;
-}
-
+# Do not use RecallsCount, it is deprecated and will be removed in a future release.
 sub RecallsCount {
     my ( $self, $biblionumber ) = @_;
 
