@@ -26,8 +26,6 @@ use C4::Context;
 use C4::Output qw( output_html_with_http_headers );
 use C4::Matcher qw/valid_normalization_routines/;
 
-my $script_name = "/cgi-bin/koha/admin/matching-rules.pl";
-
 our $input = CGI->new;
 my $op = $input->param('op') || '';
 
@@ -39,8 +37,6 @@ my ($template, $loggedinuser, $cookie)
                  flagsrequired => { parameters => 'manage_matching_rules' },
                  });
 
-$template->param(script_name => $script_name);
-
 my $matcher_id = $input->param("matcher_id");
 
 $template->param( max_matchpoint => 0 );
