@@ -24,11 +24,4 @@ export default defineConfig({
             },
         },
     },
-
-    component: {
-        devServer: {
-            framework: "vue-cli",
-            bundler: "webpack",
-        },
-    },
 });
