@@ -41,4 +41,7 @@ my $status = '400 Bad Request';
 if ( C4::Context->is_internal_PSGI_request() ) {
     $status = '200 OK';
 }
+
+#NOTE: We're not setting/updating the cookie here
+$cookie = '';
 output_with_http_headers $query, $cookie, $template->output, 'html', $status;
