@@ -114,10 +114,8 @@ if ( $backends_available ) {
         $template->param(
             notices    => $notices,
             request    => $request,
-            ( $params->{tran_error} ?
-                ( tran_error => $params->{tran_error} ) : () ),
-            ( $params->{tran_success} ?
-                ( tran_success => $params->{tran_success} ) : () ),
+            ( $params->{tran_fail}    ? ( tran_fail    => $params->{tran_fail} )    : () ),
+            ( $params->{tran_success} ? ( tran_success => $params->{tran_success} ) : () ),
         );
 
         output_and_exit( $cgi, $cookie, $template, 'unknown_ill_request' ) if !$request;
@@ -455,7 +453,7 @@ if ( $backends_available ) {
             $append .= '&tran_success=' . join(',', @{$ret->{result}->{success}});
         }
         if ($ret->{result} && scalar @{$ret->{result}->{fail}} > 0) {
-            $append .= '&tran_fail=' . join(',', @{$ret->{result}->{fail}}.join(','));
+            $append .= '&tran_fail=' . join( ',', @{ $ret->{result}->{fail} } );
         }
         # Redirect to view the whole request
         print $cgi->redirect(
