@@ -455,11 +455,8 @@ function _dt_default_ajax (params){
             function build_query(col, value){
 
                 var parts = [];
-                var attributes = col.data.split(':');
-                for (var i=0;i<attributes.length;i++){
-                    var part = {};
-                    var attr = attributes[i];
-                    let default_build = true;
+                var attributes = col.data.split(":");
+
                     let criteria = options.criteria;
                     if ( value.match(/^\^(.*)\$$/) ) {
                         value = value.replace(/^\^/, '').replace(/\$$/, '');
@@ -469,6 +466,11 @@ function _dt_default_ajax (params){
                         value = value.replace(/(\%|\\)/g, "\\$1");
                     }
 
+                for (var i = 0; i < attributes.length; i++) {
+                    var part = {};
+                    var attr = attributes[i];
+                    let default_build = true;
+
                     let built_value;
                     if ( col.type == 'date' ) {
                         let rfc3339 = $date_to_rfc3339(value);
@@ -501,8 +503,14 @@ function _dt_default_ajax (params){
                                 const search_value = value.length
                                     ? value
                                     : global_search;
+
+                                // Escape all regex metachars . * + ? ^ $ { } ( ) | [ ] \
                                 const regex = new RegExp(
-                                    `^${search_value}`,
+                                    "^" +
+                                        search_value.replace(
+                                            /[.*+?^${}()|[\]\\]/g,
+                                            "\\$&"
+                                        ),
                                     "i"
                                 );
                                 if (
@@ -694,6 +702,26 @@ function _dt_buttons(params){
         }
     }
 
+    const export_format_print = {
+        body: function (data, row, column, node) {
+            const newnode = node.cloneNode(true);
+            const no_export_nodes = newnode.querySelectorAll(".no-export");
+            no_export_nodes.forEach(child => {
+                child.parentNode.removeChild(child);
+            });
+            //Note: innerHTML is the same thing as the data variable,
+            //minus the ".no-export" nodes that we've removed
+            //Note: See dataTables.buttons.js for original function usage
+            const str = DataTable.Buttons.stripData(newnode.innerHTML, {
+                decodeEntities: false,
+                stripHtml: true,
+                stripNewlines: true,
+                trim: true,
+            });
+            return str;
+        },
+    };
+
     var export_format = {
         body: function ( data, row, column, node ) {
             var newnode = $(node);
@@ -733,7 +761,7 @@ function _dt_buttons(params){
             extend: 'print',
             exportOptions: {
                 columns: exportColumns,
-                format:  export_format
+                format:  export_format_print,
             },
         }
     ];
@@ -911,10 +939,15 @@ function _dt_add_filters(table_node, table_dt, filters_options = {}) {
                         return this._id !== "" && this._str !== "";
                     })
                     .each(function () {
-                        let optionValue =
-                            table_dt.settings()[0].ajax !== null
-                                ? `^${this._id}$`
-                                : this._id;
+                        let optionValue = this._id;
+
+                        if (
+                            table_dt.settings()[0].ajax !== null &&
+                            $(table_node)?.attr("id") !== "item_search"
+                        ) {
+                            optionValue = `^${this._id}$`;
+                        }
+
                         let o = $(
                             `<option value="${optionValue}">${this._str}</option>`
                         );
