@@ -56,17 +56,7 @@ function confirmFormatOverwrite( event ) {
     }
 }
 
-var Sticky;
-
 $(document).ready(function() {
-    if( add_form || copy_form ){
-        Sticky = $("#toolbar");
-        Sticky.hcSticky({
-            stickTo: ".main",
-            stickyClass: "floating"
-        });
-    }
-
     var ntable = KohaTable("lettert", {
         "autoWidth": false,
         "paging": false,
@@ -184,7 +174,7 @@ $(document).ready(function() {
 
     if( $("#tabs").length > 0 ){
         let langtab = $("#langtab").val();
-        $("#tabs a[data-toggle='tab']").on("shown.bs.tab", function (e) {
+        $("#tabs a[data-bs-toggle='tab']").on("shown.bs.tab", function (e) {
             var link = e.target.hash.replace("#","");
             $("#langtab").val( link );
         });
