@@ -9,25 +9,26 @@ jQuery.validator.addMethod( "restrictionDisplayText", function(value){
     var ex = Object.values(existing).map(function(el) {
         return el.toLowerCase();
     });
-    return (value.length > 0 && ex.indexOf(value.toLowerCase()) > -1) ?
+    var code = $('input[name="code"]').val();
+    return (value.length > 0 && ex.indexOf(value.toLowerCase()) > -1) && existing[code] != value ?
         false :
         true;
 }, MSG_DUPLICATE_DISPLAY_TEXT);
 
 $(document).ready(function() {
     KohaTable("restriction_types", {
-        "aoColumnDefs": [{
-            "aTargets": [-1],
-            "bSortable": false,
-            "bSearchable": false
+        "columnDefs":  [{
+            "targets":  [-1],
+            "orderable":  false,
+            "searchable":  false
         }, {
-            "aTargets": [0, 1],
-            "sType": "natural"
+            "targets":  [0, 1],
+            "type":  "natural"
         }, ],
-        "aaSorting": [
+        "order":  [
             [1, "asc"]
         ],
-        "sPaginationType": "full",
+        "pagingType":  "full",
         "exportColumns": [0,1],
     });
 
