@@ -9,16 +9,22 @@ export class AVAPIClient extends HttpClient {
 
     get values() {
         return {
-            getCategoriesWithValues: (cat_array) =>
+            get: category =>
                 this.get({
-                    endpoint: "?q={\"me.category_name\":["+(cat_array.join(", "))+"]}",
+                    endpoint: `/${category}/authorised_values`,
+                }),
+            getCategoriesWithValues: cat_array =>
+                this.get({
+                    endpoint:
+                        '?q={"me.category_name":[' +
+                        cat_array.join(", ") +
+                        "]}",
                     headers: {
-                        "x-koha-embed":
-                            "authorised_values",
+                        "x-koha-embed": "authorised_values",
                     },
-            }),
+                }),
         };
     }
 }
 
-export default AVAPIClient;
\ No newline at end of file
+export default AVAPIClient;
