@@ -1,17 +1,15 @@
-const { startDevServer } = require("@cypress/webpack-dev-server");
-const webpackConfig = require("@vue/cli-service/webpack.config.js");
+const { startDevServer } = require('@cypress/webpack-dev-server')
 
 const mysql = require("cypress-mysql");
 
 const { buildSampleObject, buildSampleObjects } = require("./mockData.js");
 
 module.exports = (on, config) => {
-    on("dev-server:start", options =>
-        startDevServer({
-            options,
-            webpackConfig,
-        })
-    );
+    on('dev-server:start', options =>
+      startDevServer({
+        options,
+      })
+    )
 
     mysql.configurePlugin(on);
 
